import React from "react";
import { reduxForm, Field } from "redux-form";

import { renderInput, renderCheckbox } from "./form-elemets";
import { todoValidate } from "../../utils/validator";

import "./style.scss";

const Form = ({
	handleSubmit,
	addItemEvent,
	initialValues,
	editItem,
	reset,
	pristine,
	submitting,
	resetInitValue
}) => {
	const submit = value => {
		if (Object.keys(initialValues).length === 0) {
			addItemEvent({
				...value,
				id: Math.random()
					.toString()
					.substr(2, 100),
				hobby: []
			});
		} else {
			editItem(value);
		}
		resetForm();
	};

	const resetForm = () => {
		reset();
		resetInitValue();
	};

	return (
		<form className="form" onSubmit={handleSubmit(submit)}>
			<Field name="firstName" label="First Name" required component={renderInput} />
			<Field name="lastName" label="Last Name" required component={renderInput} />
			<Field name="age" type="number" label="Age" required component={renderInput} />
			<Field name="editable" label="Editable" type="checkbox" required component={renderCheckbox} />

			<button disabled={pristine || submitting}>Submit</button>
			<button disabled={pristine || submitting} type="button" onClick={resetForm}>
				Clear
			</button>
		</form>
	);
};

export default reduxForm({ form: "todo", validate: todoValidate, enableReinitialize: true })(Form);
